summaryrefslogtreecommitdiff
path: root/i/marvin/src/es/es.cc
diff options
context:
space:
mode:
Diffstat (limited to 'i/marvin/src/es/es.cc')
-rw-r--r--i/marvin/src/es/es.cc10
1 files changed, 6 insertions, 4 deletions
diff --git a/i/marvin/src/es/es.cc b/i/marvin/src/es/es.cc
index 83fd1dc..e8b5f72 100644
--- a/i/marvin/src/es/es.cc
+++ b/i/marvin/src/es/es.cc
@@ -116,6 +116,8 @@ Es::reset (void)
setRVBSniffFrontStat (rvbSniffFrontStat_);
lcdGetKey (lcdKeyStat_);
+ lcdPrint ("I'm ready Tb!");
+
enableAllSensors (true);
log_ ("Es", Log::debug) << "Reset Es done.";
}
@@ -246,15 +248,15 @@ Es::setSharpThreshold (int sharp_num, int threshold_high,
proto_.send ('o', "bww", sharp_num, threshold_high, threshold_low);
}
/// Print something on the LCD (max 32 char)
void
Es::lcdPrint (const std::string &message)
{
// XXX Yerk !
- std::memset (lcd_mess_char_, '\0', 32);
+ std::memset (lcd_mess_char_, '\0', 17);
int size = message.size ();
- std::memcpy (lcd_mess_char_, message.data (), size > 32 ? 32 : size);
- proto_.send ('l', lcd_mess_char_, 32);
+ std::memcpy (lcd_mess_char_, message.data (), size > 16 ? 16 : size);
+ proto_.send ('l', lcd_mess_char_, 16);
}
/// Get the current pressed keys of the LCD
@@ -246,15 +248,15 @@ Es::setSharpThreshold (int sharp_num, int threshold_high,
proto_.send ('o', "bww", sharp_num, threshold_high, threshold_low);
}
-/// Print something on the LCD (max 32 char)
+/// Print something on the LCD (max 16 char)
void
Es::lcdPrint (const std::string &message)